@@ -21,3 +21,7 @@ except ImportError:
     JSONSchema = None
     MarshmallowValidationError = None
     MARSHMALLOW = False
+
+    def schema_to_json():
+        """provide empty implmentation for the case where
+        marshmallow importing failed."""
